@@ -1,15 +1,16 @@
-#' Get observations
+#' Get or set observations
 #'
 #' @description
 #' `observations()` gets the observations from a Camera Trap Data Package
 #'   object.
 #'
-#' `observations<-()` is the assignment equivalent.
-#'   It should only be used within other functions, where the expected data
-#'   structure can be guaranteed.
+#' `observations()<-` is the assignment equivalent.
+#' - It should only be used within other functions, where the expected data
+#' structure can be guaranteed.
+#' - Metadata (`x$taxonomic`) are updated to match the assigned observations.
 #'
 #' @inheritParams print.camtrapdp
-#' @return [tibble::tibble()] data frame with observations.
+#' @return A [tibble::tibble()] data frame with observations.
 #' @family accessor functions
 #' @export
 #' @examples
@@ -34,6 +35,11 @@ observations <- function(x) {
       class = "camtrapdp_error_assignment_wrong_class"
     )
   }
+
   purrr::pluck(x, "data", "observations") <- dplyr::as_tibble(value)
+
+  # Update taxonomic scope in metadata
+  x <- update_taxonomic(x)
+
   return(x)
 }
